@@ -2,7 +2,7 @@ use crate::error::*;
 use crate::tools::AndroidSdk;
 use std::process::Command;
 
-/// Runs `adb logcat RustStdoutStderr:D '*:S'` command
+/// Returns `adb logcat` command
 fn logcat_cmd(sdk: &AndroidSdk) -> Result<Command> {
     let mut adb = sdk.platform_tool(bin!("adb"))?;
     adb.arg("logcat");
@@ -13,7 +13,7 @@ fn logcat_cmd(sdk: &AndroidSdk) -> Result<Command> {
 /// Runs`adb logcat RustStdoutStderr:D '*:S'` command
 pub fn attach_logger_only_rust(sdk: &AndroidSdk) -> Result<()> {
     let mut adb = logcat_cmd(sdk)?;
-    adb.arg("RustStdoutStderr:D").arg("*:S");
+    adb.arg("RustStdoutStderr:D").arg("SAPP:D").arg("*:S");
     adb.spawn()?;
     Ok(())
 }
